==> 1.0.5.tar.gz: android/src/main/java/co/hyperverge/hypersnapsdk/hypersnapsdk_flutter/FLHVFaceCapture.java <==
package co.hyperverge.hypersnapsdk.hypersnapsdk_flutter;

import android.content.Context;
import android.os.Build;
import android.util.Log;

import androidx.annotation.RequiresApi;

import org.json.JSONException;
import org.json.JSONObject;

import java.util.Map;
import java.util.Objects;

import co.hyperverge.hypersnapsdk.activities.HVFaceActivity;
import co.hyperverge.hypersnapsdk.listeners.FaceCaptureCompletionHandler;
import co.hyperverge.hypersnapsdk.objects.HVError;
import co.hyperverge.hypersnapsdk.objects.HVFaceConfig;
import co.hyperverge.hypersnapsdk.objects.HVResponse;


public class FLHVFaceCapture {

    static final String FACE_CAPTURE_START = "faceCaptureStart";
    static final String FACE_CAPTURE_SET_LIVENESS_ENDPOINT =
            "faceCaptureSetLivenessEndpoint";
    static final String FACE_CAPTURE_SET_SHOULD_RETURN_FULL_IMAGE_URL =
            "faceCaptureSetShouldReturnFullImageUrl";
    static final String FACE_CAPTURE_SET_SHOULD_SHOW_CAMERA_SWITCH_BUTTON =
            "faceCaptureSetShouldShowCameraSwitchButton";
    static final String FACE_CAPTURE_SET_SHOULD_SHOW_INSTRUCTION_PAGE =
            "faceCaptureSetShouldShowInstructionPage";
    static final String FACE_CAPTURE_SET_LIVENESS_MODE =
            "faceCaptureSetLivenessMode";
    static final String FACE_CAPTURE_SET_FACE_CAPTURE_TITLE =
            "faceCaptureSetFaceCaptureTitle";
    static final String FACE_CAPTURE_SET_FACE_CAPTURE_SUBTITLE =
            "faceCaptureSetFaceCaptureSubtitle";
    static final String FACE_CAPTURE_SET_SHOULD_USE_BACK_CAMERA =
            "faceCaptureSetShouldUseBackCamera";
    static final String FACE_CAPTURE_SET_SHOULD_ADD_PADDING =
            "faceCaptureSetShouldAddPadding";
    static final String FACE_CAPTURE_SET_PADDING = "faceCaptureSetPadding";
    static final String FACE_CAPTURE_SET_LIVENESS_API_PARAMETERS =
            "faceCaptureSetLivenessAPIParameters";
    static final String FACE_CAPTURE_SET_LIVENESS_API_HEADERS =
            "faceCaptureSetLivenessAPIHeaders";
    static final String FACE_CAPTURE_SET_SHOULD_HANDLE_RETRIES =
            "faceCaptureSetShouldHandleRetries";
    static final String FACE_CAPTURE_SET_SHOULD_SHOW_CLOSE_ALERT =
            "faceCaptureSetShouldShowCloseAlert";
    static final String FACE_CAPTURE_SET_CLOSE_ALERT_DIALOG_TITLE =
            "faceCaptureSetCloseAlertDialogTitle";
    static final String FACE_CAPTURE_SET_CLOSE_ALERT_DIALOG_DESCRIPTION =
            "faceCaptureSetCloseAlertDialogDesc";
    static final String FACE_CAPTURE_SET_SHOW_TRUST_LOGOS =
            "faceCaptureSetShowTrustLogos";
    static final String FACE_CAPTURE_SET_UI_STRINGS = "faceCaptureSetUIStrings";

    private static final String FACE_CAPTURE_TITLE = "faceCaptureTitle";
    private static final String FACE_CAPTURE_SUBTITLE = "faceCaptureSubtitle";
    private static final String FACE_CAPTURE_MOVE_CLOSER = "faceCaptureMoveCloser";
    private static final String FACE_CAPTURE_FACE_FOUND = "faceCaptureFaceFound";
    private static final String FACE_CAPTURE_FACE_NOT_FOUND = "faceCaptureFaceNotFound";
    private static final String FACE_CAPTURE_MOVE_AWAY = "faceCaptureMoveAway";
    private static final String FACE_CAPTURE_MULTIPLE_FACES = "faceCaptureMultipleFaces";
    private static final String FACE_RETAKE_TITLE_TEXT = "faceRetakeTitleText";
    private static final String FACE_RETAKE_BUTTON_TEXT = "faceRetakeButtonText";
    private static final String FACE_INSTRUCTIONS_TITLE = "faceInstructionsTitle";
    private static final String FACE_INSTRUCTIONS_TOP_1 = "faceInstructionsTop1";
    private static final String FACE_INSTRUCTIONS_TOP_2 = "faceInstructionsTop2";
    private static final String FACE_INSTRUCTIONS_NO_GLASSES = "faceInstructionsNoGlasses";
    private static final String FACE_INSTRUCTIONS_BRIGHT_LIGHT = "faceInstructionsBrightLight";
    private static final String FACE_INSTRUCTIONS_NO_HAT = "faceInstructionsNoHat";
    private static final String FACE_INSTRUCTIONS_PROCEED = "faceInstructionsProceed";
    private static final String FACE_INSTRUCTIONS_PROCEED_BACK_CAM = "faceInstructionsProceedBackCam";


    private static final String TAG = FLHVFaceCapture.class.getSimpleName();
    private HVFaceConfig faceConfig;

    public void setLivenessEndpoint(String livenessEndpoint) {
        getFaceConfig().setLivenessEndpoint(livenessEndpoint);
    }

    public HVFaceConfig getFaceConfig() {
        if (this.faceConfig == null) {
            this.faceConfig = new HVFaceConfig();
        }
        return this.faceConfig;

    }


    public void setShouldReturnFullImageUrl(Boolean shouldReturnFullImageUrl) {
        getFaceConfig().setShouldReturnFullImageUrl(shouldReturnFullImageUrl);
    }


    public void setClientID(String clientID) {
        getFaceConfig().setClientID(clientID);

    }


    @RequiresApi(api = Build.VERSION_CODES.KITKAT)
    public void setCustomUIStrings(String customStrings) {
        try {
            if (customStrings != null && !customStrings.trim().isEmpty()) {
                getFaceConfig().setCustomUIStrings(new JSONObject(customStrings));
            }
        } catch (Exception e) {
            Log.e(TAG, Objects.requireNonNull(e.getMessage()));
        }
    }


    public void setShouldShowCameraSwitchButton(Boolean shouldShow) {
        getFaceConfig().setShouldShowCameraSwitchButton(shouldShow);
    }


    public void setShouldShowInstructionPage(Boolean shouldShowInstructionPage) {
        getFaceConfig().setShouldShowInstructionPage(shouldShowInstructionPage);
    }


    @RequiresApi(api = Build.VERSION_CODES.KITKAT)
    public void setLivenessMode(String livenessValue) {
        try {
            String liveness = livenessValue.split("\\.")[1];
            HVFaceConfig.LivenessMode livenessMode = HVFaceConfig.LivenessMode.valueOf(liveness);
            getFaceConfig().setLivenessMode(livenessMode);
        } catch (Exception exp) {
            Log.e(TAG, Objects.requireNonNull(exp.getMessage()));
        }
    }


    public void setFaceCaptureTitle(String faceCaptureTitle) {
        getFaceConfig().setFaceCaptureTitle(faceCaptureTitle);
    }

    public void setFaceCaptureSubTitle(String faceCaptureSubTitle) {
        getFaceConfig().setFaceCaptureSubtitle(faceCaptureSubTitle);
    }

    public void setShouldUseBackCamera(Boolean shouldUseBackCamera) {
        getFaceConfig().setShouldUseBackCamera(shouldUseBackCamera);
    }


    public void setShouldEnableDataLogging(Boolean dataLogging) {
        getFaceConfig().setShouldEnableDataLogging(dataLogging);
    }


    public void setShouldAddPadding(Boolean shouldSetPadding) {
        getFaceConfig().setShouldEnablePadding(shouldSetPadding);

    }


    public void setPadding(double leftPadding, double rightPadding, double topPadding, double bottomPadding) {
        getFaceConfig().setPadding((float) (leftPadding), (float) rightPadding, (float) topPadding, (float) bottomPadding);
    }


    @RequiresApi(api = Build.VERSION_CODES.KITKAT)
    public void setLivenessAPIParameters(String params) {
        try {
            getFaceConfig().setLivenessAPIParameters(new JSONObject(params));
        } catch (JSONException e) {
            Log.e(TAG, Objects.requireNonNull(e.getMessage()));
        }
    }


    @RequiresApi(api = Build.VERSION_CODES.KITKAT)
    public void setLivenessAPIHeaders(String headers) {
        try {
            getFaceConfig().setLivenessAPIHeaders(new JSONObject(headers));
        } catch (JSONException e) {
            Log.e(TAG, Objects.requireNonNull(e.getMessage()));
        }
    }

    public void setShouldHandleRetries(boolean shouldHandleRetries) {
        getFaceConfig().setShouldHandleRetries(shouldHandleRetries);
    }

    public void setShouldShowCloseAlert(boolean shouldShowCloseAlert) {
        getFaceConfig().setShouldShowCloseAlert(shouldShowCloseAlert);
    }

    public void setCloseAlertDialogTitle(String closeAlertDialogTitle) {
        getFaceConfig().setCloseAlertDialogTitle(closeAlertDialogTitle);
    }

    public void setCloseAlertDialogDescription(String closeAlertDialogDescription) {
        getFaceConfig().setCloseAlertDialogDesc(closeAlertDialogDescription);
    }

    public void setShouldShowTrustLogos(boolean shouldShowTrustLogos) {
        getFaceConfig().setShowTrustLogos(shouldShowTrustLogos);
    }

    public void start(Context context, final FaceCaptureCompletionHandler callback) {

        HVFaceActivity.start(context, getFaceConfig(), new FaceCaptureCompletionHandler() {
            @RequiresApi(api = Build.VERSION_CODES.KITKAT)
            @Override
            public void onResult(HVError error, HVResponse hvResponse) {
                callback.onResult(error, hvResponse);
            }
        });

    }


    public void setUIStrings(Map<String, Object> uiStrings) {
        try {
            JSONObject uiStringsJsonObject = FLHVNetworkHelper.convertMapToJson(uiStrings);
            JSONObject customUIStrings = new JSONObject();

            if (uiStringsJsonObject.has(FACE_CAPTURE_TITLE)) {
                getFaceConfig().setFaceCaptureTitle(uiStringsJsonObject.getString(FACE_CAPTURE_TITLE));
            }

            if (uiStringsJsonObject.has(FACE_CAPTURE_SUBTITLE)) {
                getFaceConfig().setFaceCaptureSubtitle(uiStringsJsonObject.getString(FACE_CAPTURE_SUBTITLE));
            }

            if (uiStringsJsonObject.has(FACE_CAPTURE_MOVE_CLOSER)) {
                customUIStrings.put("moveCloser", uiStringsJsonObject.getString(FACE_CAPTURE_MOVE_CLOSER));
            }

            if (uiStringsJsonObject.has(FACE_CAPTURE_FACE_FOUND)) {
                customUIStrings.put(FACE_CAPTURE_FACE_FOUND, uiStringsJsonObject.getString(FACE_CAPTURE_FACE_FOUND));
            }

            if (uiStringsJsonObject.has(FACE_CAPTURE_FACE_NOT_FOUND)) {
                customUIStrings.put(FACE_CAPTURE_FACE_NOT_FOUND, uiStringsJsonObject.getString(FACE_CAPTURE_FACE_NOT_FOUND));
            }

            if (uiStringsJsonObject.has(FACE_CAPTURE_MOVE_AWAY)) {
                customUIStrings.put(FACE_CAPTURE_MOVE_AWAY, uiStringsJsonObject.getString(FACE_CAPTURE_MOVE_AWAY));
            }

            if (uiStringsJsonObject.has(FACE_CAPTURE_MULTIPLE_FACES)) {
                customUIStrings.put(FACE_CAPTURE_MULTIPLE_FACES, uiStringsJsonObject.getString(FACE_CAPTURE_MULTIPLE_FACES));
            }

            if (uiStringsJsonObject.has(FACE_INSTRUCTIONS_TITLE)) {
                customUIStrings.put(FACE_INSTRUCTIONS_TITLE, uiStringsJsonObject.getString(FACE_INSTRUCTIONS_TITLE));
            }

            if (uiStringsJsonObject.has(FACE_INSTRUCTIONS_TOP_1)) {
                customUIStrings.put(FACE_INSTRUCTIONS_TOP_1, uiStringsJsonObject.getString(FACE_INSTRUCTIONS_TOP_1));
            }

            if (uiStringsJsonObject.has(FACE_INSTRUCTIONS_TOP_2)) {
                customUIStrings.put(FACE_INSTRUCTIONS_TOP_2, uiStringsJsonObject.getString(FACE_INSTRUCTIONS_TOP_2));
            }

            if (uiStringsJsonObject.has(FACE_INSTRUCTIONS_NO_GLASSES)) {
                customUIStrings.put(FACE_INSTRUCTIONS_NO_GLASSES, uiStringsJsonObject.getString(FACE_INSTRUCTIONS_NO_GLASSES));
            }

            if (uiStringsJsonObject.has(FACE_INSTRUCTIONS_BRIGHT_LIGHT)) {
                customUIStrings.put(FACE_INSTRUCTIONS_BRIGHT_LIGHT, uiStringsJsonObject.getString(FACE_INSTRUCTIONS_BRIGHT_LIGHT));
            }

            if (uiStringsJsonObject.has(FACE_INSTRUCTIONS_NO_HAT)) {
                customUIStrings.put(FACE_INSTRUCTIONS_NO_HAT, uiStringsJsonObject.getString(FACE_INSTRUCTIONS_NO_HAT));
            }

            if (uiStringsJsonObject.has(FACE_INSTRUCTIONS_PROCEED)) {
                customUIStrings.put(FACE_INSTRUCTIONS_PROCEED, uiStringsJsonObject.getString(FACE_INSTRUCTIONS_PROCEED));
            }

            if (uiStringsJsonObject.has(FACE_INSTRUCTIONS_PROCEED_BACK_CAM)) {
                customUIStrings.put(FACE_INSTRUCTIONS_PROCEED_BACK_CAM, uiStringsJsonObject.getString(FACE_INSTRUCTIONS_PROCEED_BACK_CAM));
            }

            if (uiStringsJsonObject.has(FACE_RETAKE_TITLE_TEXT)) {
                getFaceConfig().setErrorReviewTitle(uiStringsJsonObject.getString(FACE_RETAKE_TITLE_TEXT));
            }

            if (uiStringsJsonObject.has(FACE_RETAKE_BUTTON_TEXT)) {
                getFaceConfig().setErrorReviewRetakeButton(uiStringsJsonObject.getString(FACE_RETAKE_BUTTON_TEXT));
            }

            //  TODO : Fix this in FaceInstructionActivity android native sdk
            customUIStrings.put("faceInstructionsTitleTypeFace", 0);
            customUIStrings.put("faceInstructionsTop1TypeFace", 0);
            customUIStrings.put("faceInstructionsTop2TypeFace", 0);
            customUIStrings.put("faceInstructionsBrightLightTypeFace", 0);
            customUIStrings.put("faceInstructionsNoHatTypeFace", 0);
            customUIStrings.put("faceInstructionsNoGlassesTypeFace", 0);
            customUIStrings.put("faceInstructionsProceedBackCamTypeFace", 0);

            getFaceConfig().setCustomUIStrings(customUIStrings);

        } catch (JSONException e) {
            Log.e(TAG, e.getMessage());
        }
    }


}

==> 1.0.10.tar.gz: android/src/main/java/co/hyperverge/hypersnapsdk/hypersnapsdk_flutter/FLHVFaceCapture.java <==
package co.hyperverge.hypersnapsdk.hypersnapsdk_flutter;

import android.content.Context;
import android.os.Build;
import android.util.Log;

import androidx.annotation.RequiresApi;

import org.json.JSONException;
import org.json.JSONObject;

import java.util.Map;
import java.util.Objects;

import co.hyperverge.hypersnapsdk.activities.HVFaceActivity;
import co.hyperverge.hypersnapsdk.listeners.FaceCaptureCompletionHandler;
import co.hyperverge.hypersnapsdk.objects.HVError;
import co.hyperverge.hypersnapsdk.objects.HVFaceConfig;
import co.hyperverge.hypersnapsdk.objects.HVResponse;


public class FLHVFaceCapture {

    static final String FACE_CAPTURE_START = "faceCaptureStart";
    static final String FACE_CAPTURE_SET_LIVENESS_ENDPOINT =
            "faceCaptureSetLivenessEndpoint";
    static final String FACE_CAPTURE_SET_SHOULD_RETURN_FULL_IMAGE_URL =
            "faceCaptureSetShouldReturnFullImageUrl";
    static final String FACE_CAPTURE_SET_SHOULD_SHOW_CAMERA_SWITCH_BUTTON =
            "faceCaptureSetShouldShowCameraSwitchButton";
    static final String FACE_CAPTURE_SET_SHOULD_SHOW_INSTRUCTION_PAGE =
            "faceCaptureSetShouldShowInstructionPage";
    static final String FACE_CAPTURE_SET_VIDEO_RECORDING =
            "faceCaptureSetVideoRecording";
    static final String FACE_CAPTURE_SET_LIVENESS_MODE =
            "faceCaptureSetLivenessMode";
    static final String FACE_CAPTURE_SET_FACE_CAPTURE_TITLE =
            "faceCaptureSetFaceCaptureTitle";
    static final String FACE_CAPTURE_SET_FACE_CAPTURE_SUBTITLE =
            "faceCaptureSetFaceCaptureSubtitle";
    static final String FACE_CAPTURE_SET_SHOULD_USE_BACK_CAMERA =
            "faceCaptureSetShouldUseBackCamera";
    static final String FACE_CAPTURE_SET_SHOULD_ADD_PADDING =
            "faceCaptureSetShouldAddPadding";
    static final String FACE_CAPTURE_SET_PADDING = "faceCaptureSetPadding";
    static final String FACE_CAPTURE_SET_LIVENESS_API_PARAMETERS =
            "faceCaptureSetLivenessAPIParameters";
    static final String FACE_CAPTURE_SET_LIVENESS_API_HEADERS =
            "faceCaptureSetLivenessAPIHeaders";
    static final String FACE_CAPTURE_SET_SHOULD_HANDLE_RETRIES =
            "faceCaptureSetShouldHandleRetries";
    static final String FACE_CAPTURE_SET_SHOULD_SHOW_CLOSE_ALERT =
            "faceCaptureSetShouldShowCloseAlert";
    static final String FACE_CAPTURE_SET_CLOSE_ALERT_DIALOG_TITLE =
            "faceCaptureSetCloseAlertDialogTitle";
    static final String FACE_CAPTURE_SET_CLOSE_ALERT_DIALOG_DESCRIPTION =
            "faceCaptureSetCloseAlertDialogDesc";
    static final String FACE_CAPTURE_SET_SHOW_TRUST_LOGOS =
            "faceCaptureSetShowTrustLogos";
    static final String FACE_CAPTURE_SET_UI_STRINGS = "faceCaptureSetUIStrings";

    private static final String FACE_CAPTURE_TITLE = "faceCaptureTitle";
    private static final String FACE_CAPTURE_SUBTITLE = "faceCaptureSubtitle";
    private static final String FACE_CAPTURE_MOVE_CLOSER = "faceCaptureMoveCloser";
    private static final String FACE_CAPTURE_FACE_FOUND = "faceCaptureFaceFound";
    private static final String FACE_CAPTURE_FACE_NOT_FOUND = "faceCaptureFaceNotFound";
    private static final String FACE_CAPTURE_MOVE_AWAY = "faceCaptureMoveAway";
    private static final String FACE_CAPTURE_MULTIPLE_FACES = "faceCaptureMultipleFaces";
    private static final String FACE_RETAKE_TITLE_TEXT = "faceRetakeTitleText";
    private static final String FACE_RETAKE_BUTTON_TEXT = "faceRetakeButtonText";
    private static final String FACE_INSTRUCTIONS_TITLE = "faceInstructionsTitle";
    private static final String FACE_INSTRUCTIONS_TOP_1 = "faceInstructionsTop1";
    private static final String FACE_INSTRUCTIONS_TOP_2 = "faceInstructionsTop2";
    private static final String FACE_INSTRUCTIONS_NO_GLASSES = "faceInstructionsNoGlasses";
    private static final String FACE_INSTRUCTIONS_BRIGHT_LIGHT = "faceInstructionsBrightLight";
    private static final String FACE_INSTRUCTIONS_NO_HAT = "faceInstructionsNoHat";
    private static final String FACE_INSTRUCTIONS_PROCEED = "faceInstructionsProceed";
    private static final String FACE_INSTRUCTIONS_PROCEED_BACK_CAM = "faceInstructionsProceedBackCam";


    private static final String TAG = FLHVFaceCapture.class.getSimpleName();
    private HVFaceConfig faceConfig;

    public void setLivenessEndpoint(String livenessEndpoint) {
        getFaceConfig().setLivenessEndpoint(livenessEndpoint);
    }

    public HVFaceConfig getFaceConfig() {
        if (this.faceConfig == null) {
            this.faceConfig = new HVFaceConfig();
        }
        return this.faceConfig;

    }


    public void setShouldReturnFullImageUrl(Boolean shouldReturnFullImageUrl) {
        getFaceConfig().setShouldReturnFullImageUrl(shouldReturnFullImageUrl);
    }


    public void setClientID(String clientID) {
        getFaceConfig().setClientID(clientID);

    }


    @RequiresApi(api = Build.VERSION_CODES.KITKAT)
    public void setCustomUIStrings(String customStrings) {
        try {
            if (customStrings != null && !customStrings.trim().isEmpty()) {
                getFaceConfig().setCustomUIStrings(new JSONObject(customStrings));
            }
        } catch (Exception e) {
            Log.e(TAG, Objects.requireNonNull(e.getMessage()));
        }
    }


    public void setShouldShowCameraSwitchButton(Boolean shouldShow) {
        getFaceConfig().setShouldShowCameraSwitchButton(shouldShow);
    }


    public void setShouldShowInstructionPage(Boolean shouldShowInstructionPage) {
        getFaceConfig().setShouldShowInstructionPage(shouldShowInstructionPage);
    }


    @RequiresApi(api = Build.VERSION_CODES.KITKAT)
    public void setLivenessMode(String livenessValue) {
        try {
            String liveness = livenessValue.split("\\.")[1];
            HVFaceConfig.LivenessMode livenessMode = HVFaceConfig.LivenessMode.valueOf(liveness);
            getFaceConfig().setLivenessMode(livenessMode);
        } catch (Exception exp) {
            Log.e(TAG, Objects.requireNonNull(exp.getMessage()));
        }
    }

    public void setVideoRecording(boolean shouldRecordVideo, int numberOfFrames, double bitrateM, int fps) {
        if (shouldRecordVideo) {
            getFaceConfig().setBitrateM(bitrateM);
            getFaceConfig().setNumberOfFrames(numberOfFrames);
            getFaceConfig().setFps(fps);
        }
        getFaceConfig().setShouldRecordVideo(shouldRecordVideo);
    }


    public void setFaceCaptureTitle(String faceCaptureTitle) {
        getFaceConfig().setFaceCaptureTitle(faceCaptureTitle);
    }

    public void setFaceCaptureSubTitle(String faceCaptureSubTitle) {
        getFaceConfig().setFaceCaptureSubtitle(faceCaptureSubTitle);
    }

    public void setShouldUseBackCamera(Boolean shouldUseBackCamera) {
        getFaceConfig().setShouldUseBackCamera(shouldUseBackCamera);
    }


    public void setShouldEnableDataLogging(Boolean dataLogging) {
        getFaceConfig().setShouldEnableDataLogging(dataLogging);
    }


    public void setShouldAddPadding(Boolean shouldSetPadding) {
        getFaceConfig().setShouldEnablePadding(shouldSetPadding);

    }


    public void setPadding(double leftPadding, double rightPadding, double topPadding, double bottomPadding) {
        getFaceConfig().setPadding((float) (leftPadding), (float) rightPadding, (float) topPadding, (float) bottomPadding);
    }

    public void setLivenessAPIParameters(Map<String, Object> params) {
        JSONObject paramsObj = new JSONObject();
        try {
            if (params != null) {
                paramsObj = FLHVNetworkHelper.convertMapToJson(params);
            }
        } catch (Exception e) {
            Log.e(TAG, e.getMessage());
        }
        getFaceConfig().setLivenessAPIParameters(paramsObj);
    }

    public void setLivenessAPIHeaders(Map<String, Object> headers) {
        JSONObject headersObj = new JSONObject();
        try {
            if (headers != null) {
                headersObj = FLHVNetworkHelper.convertMapToJson(headers);
            }
        } catch (Exception e) {
            Log.e(TAG, e.getMessage());
        }
        getFaceConfig().setLivenessAPIHeaders(headersObj);
    }

    public void setShouldHandleRetries(boolean shouldHandleRetries) {
        getFaceConfig().setShouldHandleRetries(shouldHandleRetries);
    }

    public void setShouldShowCloseAlert(boolean shouldShowCloseAlert) {
        getFaceConfig().setShouldShowCloseAlert(shouldShowCloseAlert);
    }

    public void setCloseAlertDialogTitle(String closeAlertDialogTitle) {
        getFaceConfig().setCloseAlertDialogTitle(closeAlertDialogTitle);
    }

    public void setCloseAlertDialogDescription(String closeAlertDialogDescription) {
        getFaceConfig().setCloseAlertDialogDesc(closeAlertDialogDescription);
    }

    public void setShouldShowTrustLogos(boolean shouldShowTrustLogos) {
        getFaceConfig().setShowTrustLogos(shouldShowTrustLogos);
    }

    public void start(Context context, final FaceCaptureCompletionHandler callback) {

        HVFaceActivity.start(context, getFaceConfig(), new FaceCaptureCompletionHandler() {
            @RequiresApi(api = Build.VERSION_CODES.KITKAT)
            @Override
            public void onResult(HVError error, HVResponse hvResponse) {
                callback.onResult(error, hvResponse);
            }
        });

    }


    public void setUIStrings(Map<String, Object> uiStrings) {
        try {
            JSONObject uiStringsJsonObject = FLHVNetworkHelper.convertMapToJson(uiStrings);
            JSONObject customUIStrings = new JSONObject();

            if (uiStringsJsonObject.has(FACE_CAPTURE_TITLE)) {
                getFaceConfig().setFaceCaptureTitle(uiStringsJsonObject.getString(FACE_CAPTURE_TITLE));
            }

            if (uiStringsJsonObject.has(FACE_CAPTURE_SUBTITLE)) {
                getFaceConfig().setFaceCaptureSubtitle(uiStringsJsonObject.getString(FACE_CAPTURE_SUBTITLE));
            }

            if (uiStringsJsonObject.has(FACE_CAPTURE_MOVE_CLOSER)) {
                customUIStrings.put("moveCloser", uiStringsJsonObject.getString(FACE_CAPTURE_MOVE_CLOSER));
            }

            if (uiStringsJsonObject.has(FACE_CAPTURE_FACE_FOUND)) {
                customUIStrings.put(FACE_CAPTURE_FACE_FOUND, uiStringsJsonObject.getString(FACE_CAPTURE_FACE_FOUND));
            }

            if (uiStringsJsonObject.has(FACE_CAPTURE_FACE_NOT_FOUND)) {
                customUIStrings.put(FACE_CAPTURE_FACE_NOT_FOUND, uiStringsJsonObject.getString(FACE_CAPTURE_FACE_NOT_FOUND));
            }

            if (uiStringsJsonObject.has(FACE_CAPTURE_MOVE_AWAY)) {
                customUIStrings.put(FACE_CAPTURE_MOVE_AWAY, uiStringsJsonObject.getString(FACE_CAPTURE_MOVE_AWAY));
            }

            if (uiStringsJsonObject.has(FACE_CAPTURE_MULTIPLE_FACES)) {
                customUIStrings.put(FACE_CAPTURE_MULTIPLE_FACES, uiStringsJsonObject.getString(FACE_CAPTURE_MULTIPLE_FACES));
            }

            if (uiStringsJsonObject.has(FACE_INSTRUCTIONS_TITLE)) {
                customUIStrings.put(FACE_INSTRUCTIONS_TITLE, uiStringsJsonObject.getString(FACE_INSTRUCTIONS_TITLE));
            }

            if (uiStringsJsonObject.has(FACE_INSTRUCTIONS_TOP_1)) {
                customUIStrings.put(FACE_INSTRUCTIONS_TOP_1, uiStringsJsonObject.getString(FACE_INSTRUCTIONS_TOP_1));
            }

            if (uiStringsJsonObject.has(FACE_INSTRUCTIONS_TOP_2)) {
                customUIStrings.put(FACE_INSTRUCTIONS_TOP_2, uiStringsJsonObject.getString(FACE_INSTRUCTIONS_TOP_2));
            }

            if (uiStringsJsonObject.has(FACE_INSTRUCTIONS_NO_GLASSES)) {
                customUIStrings.put(FACE_INSTRUCTIONS_NO_GLASSES, uiStringsJsonObject.getString(FACE_INSTRUCTIONS_NO_GLASSES));
            }

            if (uiStringsJsonObject.has(FACE_INSTRUCTIONS_BRIGHT_LIGHT)) {
                customUIStrings.put(FACE_INSTRUCTIONS_BRIGHT_LIGHT, uiStringsJsonObject.getString(FACE_INSTRUCTIONS_BRIGHT_LIGHT));
            }

            if (uiStringsJsonObject.has(FACE_INSTRUCTIONS_NO_HAT)) {
                customUIStrings.put(FACE_INSTRUCTIONS_NO_HAT, uiStringsJsonObject.getString(FACE_INSTRUCTIONS_NO_HAT));
            }

            if (uiStringsJsonObject.has(FACE_INSTRUCTIONS_PROCEED)) {
                customUIStrings.put(FACE_INSTRUCTIONS_PROCEED, uiStringsJsonObject.getString(FACE_INSTRUCTIONS_PROCEED));
            }

            if (uiStringsJsonObject.has(FACE_INSTRUCTIONS_PROCEED_BACK_CAM)) {
                customUIStrings.put(FACE_INSTRUCTIONS_PROCEED_BACK_CAM, uiStringsJsonObject.getString(FACE_INSTRUCTIONS_PROCEED_BACK_CAM));
            }

            if (uiStringsJsonObject.has(FACE_RETAKE_TITLE_TEXT)) {
                getFaceConfig().setErrorReviewTitle(uiStringsJsonObject.getString(FACE_RETAKE_TITLE_TEXT));
            }

            if (uiStringsJsonObject.has(FACE_RETAKE_BUTTON_TEXT)) {
                getFaceConfig().setErrorReviewRetakeButton(uiStringsJsonObject.getString(FACE_RETAKE_BUTTON_TEXT));
            }

            getFaceConfig().setCustomUIStrings(customUIStrings);

        } catch (JSONException e) {
            Log.e(TAG, e.getMessage());
        }
    }


}
